:mod:`dynamixel` Package
========================

.. autofunction:: pypot.dynamixel.get_available_ports

.. autofunction:: pypot.dynamixel.find_port

.. autofunction:: pypot.dynamixel.autodetect_robot


:mod:`~pypot.dynamixel.io` Package
----------------------------------

.. automodule:: pypot.dynamixel.io
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pypot.dynamixel.io.io
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pypot.dynamixel.io.io_320
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`motor` Module
-------------------

.. automodule:: pypot.dynamixel.motor
    :members:
    :show-inheritance:

.. autoattribute:: pypot.dynamixel.motor.DxlMotor.registers


:mod:`controller` Module
------------------------

.. automodule:: pypot.dynamixel.controller
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`error` Module
-------------------

.. automodule:: pypot.dynamixel.error
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`conversion` Module
------------------------

.. automodule:: pypot.dynamixel.conversion
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`protocol` Package
-----------------------

:mod:`v1` Module
++++++++++++++++

.. automodule:: pypot.dynamixel.protocol.v1
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`v2` Module
++++++++++++++++

.. automodule:: pypot.dynamixel.protocol.v2
    :members:
    :undoc-members:
    :show-inheritance:
